<div class="modal fade" id="bsmodals-error" tabindex="-1" role="dialog"
    {% if no_click_off %} data-backdrop="static" {% endif %}
    aria-labelledby="bsmodals-error-title" aria-hidden="true">
  <div class="modal-dialog {% if not not_centered %}modal-dialog-centered{% endif %}" 
      role="document">
    <div class="modal-content">

      <div class="modal-header">
        <h5>Error</h5>
        <button type="button" class="close" data-dismiss="modal"
            aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>

      <div class="modal-body">
        <p id="bsmodals-error-body"></p>
      </div>

      <div class="modal-footer">
        <button id="bsmodals-error-close" type="button" data-dismiss="modal"
          >Close</button>
      </div>

    </div>
  </div>
</div>
