<div class="modal fade" id="{{dialog_id}}" tabindex="-1" role="dialog"
    {% if no_click_off %} data-backdrop="static" {% endif %}
    aria-labelledby="{{dialog_id}}-title" aria-hidden="true">
  <div class="modal-dialog {% if not not_centered %}modal-dialog-centered{% endif %} {% if modal_size %}{{modal_size}}{% endif %}" 
      role="document">
    <div class="modal-content">

      <div class="modal-header">
        <h5 id="{{dialog_id}}-title">{{title}}</h5>
        {% if not hide_cancel %}
          <button type="button" class="close" data-dismiss="modal"
              aria-label="Close">
            <span aria-hidden="true">&times;</span>
          </button>
        {% endif %}
      </div>

      <div class="modal-body">
        {% block body %}
        {% endblock body %}
      </div>

      <div class="modal-footer">
        {% block footer %}
        {% endblock footer %}
      </div>

    </div>
  </div>
</div>
